import fs from "fs-extra";
import path from "path";
import { TEMPLATES } from "./config.js";
function generateReadmeContent(config) {
    const setupSteps = config.projectType === "frontend"
        ? "npm run dev or yarn dev"
        : "npm run start or yarn start";
    return `# ${config.projectName}

## Description
A ${config.projectType} application created with TypeScript.

## Installation

1. Clone the repository:
\`\`\`bash
git clone [your-repository-url]
cd ${config.projectName}
\`\`\`

2. Install dependencies:
\`\`\`bash
yarn install
\`\`\`

3. Create a .env file in the root directory and add your environment variables:
\`\`\`
NODE_ENV=development
PORT=3000
\`\`\`

## Available Scripts

- \`start\`: Starts the development server (${setupSteps})
- \`build\`: Builds the application for production
- \`lint\`: Lints the codebase
- \`format\`: Formats the codebase

## Project Structure

\`\`\`
${config.projectName}/
├── src/
│   └── ${config.projectType === "frontend" ? "App.tsx" : "index.ts"}
├── .env
├── .gitignore
├── package.json
└── README.md
\`\`\`

## License

This project is licensed under the MIT License.
`;
}
export async function copyTemplateFiles(config, projectPath) {
    const packageJson = {
        name: config.projectName,
        version: "1.0.0",
        type: "module",
        scripts: config.projectType === "frontend"
            ? {
                start: "vite",
                build: "tsc && vite build",
                lint: "eslint -c .eslintrc.cjs --ext .ts,tsx src --fix",
                format: 'prettier --write "src/**/*.{ts,tsx,json,md,js}"',
            }
            : {
                start: "nodemon --exec tsx --env-file=.env src/index.ts",
                build: "tsc",
                lint: "eslint -c .eslintrc.cjs --ext .ts src --fix",
                format: 'prettier --write "src/**/*.{ts,json,md,js}"',
            },
        dependencies: TEMPLATES[config.projectType].dependencies,
        devDependencies: TEMPLATES[config.projectType].devDependencies,
    };
    // Write package.json
    await fs.writeFile(path.join(projectPath, "package.json"), JSON.stringify(packageJson, null, 2));
    // Create README.md
    const readmeContent = generateReadmeContent(config);
    await fs.writeFile(path.join(projectPath, "README.md"), readmeContent);
    // Create src directory and entry file
    await fs.mkdir(path.join(projectPath, "src"));
    if (config.projectType === "frontend") {
        await fs.writeFile(path.join(projectPath, "src", "App.tsx"), `import React from 'react';

function App() {
    return (
        <div>
            <h1>Welcome to ${config.projectName}</h1>
        </div>
    );
}

export default App;`);
    }
    else {
        await fs.writeFile(path.join(projectPath, "src", "index.ts"), `console.log('Welcome to ${config.projectName}');`);
    }
    // Create .env file
    await fs.writeFile(path.join(projectPath, ".env"), "NODE_ENV=development\nPORT=3000\n");
}
//# sourceMappingURL=templates.js.map